# spec file for package ibus-typing-booster
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define __python3 /usr/bin/python3
Name:       ibus-typing-booster
Version:    1.5.17
Release:    1%{?dist}
Summary:    A completion input method
License:    GPL-3.0+
Group:      System Environment/Libraries
URL:        https://mike-fabian.github.io/ibus-typing-booster/
Source0:    https://fedorahosted.org/releases/i/b/ibus-typing-booster/%{name}-%{version}.tar.gz
Source1:    https://fedorahosted.org/releases/i/n/inscript2/inscript2-20160423.tar.gz
Requires:   ibus >= 1.5.3
Requires:   m17n-lib
Requires:   python3 >= 3.3
Requires:   dbus-1-python3
Requires:   python3-pyenchant
# Recommend a reasonably good font which has most of the emoji:
Recommends: gdouros-symbola-fonts
BuildRequires:  ibus-devel
BuildRequires:  python3-devel
# for the unit tests
BuildRequires:  m17n-lib
BuildRequires:  m17n-db
BuildRequires:  python3-pyenchant
%if 0%{?suse_version} == 1320
BuildRequires:  myspell-cs_CZ
BuildRequires:  myspell-de
BuildRequires:  myspell-en
BuildRequires:  myspell-es
BuildRequires:  myspell-it_IT
%else
BuildRequires:  myspell-cs_CZ
BuildRequires:  myspell-de
BuildRequires:  myspell-de_DE
BuildRequires:  myspell-en
BuildRequires:  myspell-en_US
BuildRequires:  myspell-es
BuildRequires:  myspell-es_ES
BuildRequires:  myspell-it_IT
%endif
BuildRequires:  desktop-file-utils
BuildRequires:  python3-gobject
BuildRequires:  dbus-1-x11
BuildRequires:  fdupes

%description
Ibus-typing-booster is a context sensitive completion
input method to speedup typing.

%prep
%setup -q

##extract inscript2 maps
tar xzf %{SOURCE1}

%build
export PYTHON=%{__python3}
%configure --disable-static --disable-additional --libexecdir=%{_prefix}/%{_lib}/ibus
make %{?_smp_mflags}

%install 
export PYTHON=%{__python3}
make install DESTDIR=${RPM_BUILD_ROOT} NO_INDEX=true  INSTALL="install -p"   pkgconfigdir=%{_datadir}/pkgconfig
gzip --force --best $RPM_BUILD_ROOT/%{_datadir}/%{name}/data/*.{xml,txt,json}

rm $RPM_BUILD_ROOT%{_datadir}/pkgconfig/%{name}.pc

#install inscript2 keymaps
mkdir -p $RPM_BUILD_ROOT%{_datadir}/m17n/icons
cp -p inscript2/IM/* $RPM_BUILD_ROOT%{_datadir}/m17n/
cp -p inscript2/icons/* $RPM_BUILD_ROOT%{_datadir}/m17n/icons

%fdupes %{buildroot}/%{_prefix}

%find_lang %{name}

%check
export LC_ALL=en_US.UTF-8
export M17NDIR=$RPM_BUILD_ROOT%{_datadir}/m17n/
desktop-file-validate \
    $RPM_BUILD_ROOT%{_datadir}/applications/ibus-setup-typing-booster.desktop
pushd engine
    # run doctests
    python3 hunspell_suggest.py
    python3 m17n_translit.py
    python3 itb_emoji.py
    python3 itb_util.py
popd
eval $(dbus-launch --sh-syntax)
dconf dump /
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/offtherecord false
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/usedigitsasselectkeys true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/tabenable false
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/inputmethod "'NoIme'"
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/adddirectinput false
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/rememberlastusedpreeditime true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/mincharcomplete 1
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/dictionary "'en_US'"
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/emojipredictions true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/autocommitcharacters "''"
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/pagesize 6
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/shownumberofcandidates true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/showstatusinfoinaux true
dconf dump /
ibus-daemon -drx
make check || cat ./tests/test-suite.log

%post
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :

%postun
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :

%files -f %{name}.lang
%doc AUTHORS COPYING README 
%{_datadir}/%{name}
%dir %{_datadir}/appdata
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/ibus/component/typing-booster.xml
%{_libdir}/ibus/ibus-engine-typing-booster
%{_libdir}/ibus/ibus-setup-typing-booster
%{_datadir}/applications/ibus-setup-typing-booster.desktop
%dir %{_datadir}/m17n
%{_datadir}/m17n/*.mim
%dir %{_datadir}/m17n/icons
%{_datadir}/m17n/icons/*.png

%changelog
